use crate::conf::get_config;

/// Checks if a domain is present in the blacklist of unwanted domains.
///
/// If a match is found, it immediately returns `true`. Otherwise, it returns `false`.
pub fn check_blacklist(domain: &str) -> bool {
    let conf = get_config();
    let conf = conf.websites.as_ref();

    let blacklisted_domains = conf
        .map(|x| x.BLACKLIST_DOMAINS.as_ref())
        .unwrap_or_default();

    for domain_regex in blacklisted_domains.unwrap_or(&Vec::new()) {
        let rgx = regex::Regex::new(domain_regex).unwrap();
        if rgx.is_match(domain) {
            return true;
        }
    }

    false
}
